@@ -17,7 +17,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#  $Id: dpkg-cross.pl,v 1.25 2005/02/23 14:46:58 yoush-guest Exp $
+#  $Id: dpkg-cross.pl,v 1.26 2005/05/13 18:43:34 yoush-guest Exp $
 
 # Determine if the system wide or user defined cross-compile configuration
 # have to be read.
@@ -67,7 +67,8 @@ $DPKGCROSSVERSION = "1.18";
 	'freebsd-i386' => 'i386-freebsd',
 	'darwin-powerpc' => 'powerpc-darwin',
 	'darwin-i386' => 'i386-darwin',
-	'win32-i386' => 'i386-cygwin');
+	'win32-i386' => 'i386-cygwin',
+	'amd64' => 'x86_64-linux');
 
 # Regexps to parse 'file' output to detect arch of ELF binary
 # Note that it is not always possibe to restore Debian architecture
@@ -91,6 +92,7 @@ $DPKGCROSSVERSION = "1.18";
 	's390x' => 'ELF 64-bit MSB .* S.390',
 	'ia64' => 'ELF 64-bit LSB .* IA-64',
  	'm32r' => 'ELF 32-bit MSB .* M32R',
+	'amd64' => ' ELF 64-bit LSB .* x86-64',
 	'AR' => 'current ar archive');
 
 # Lists of possible crossprefix'es for each architecture
@@ -109,7 +111,8 @@ $DPKGCROSSVERSION = "1.18";
 	"s390" => [ "s390-linux-", "s390x-linux-" ],
 	"s390x" => [ "s390x-linux-", "s390-linux-" ],
 	"ia64" => [ "ia64-linux-" ],
-	"m32r" => [ "m32r-linux-" ]);
+	"m32r" => [ "m32r-linux-" ],
+	"amd64" => [ "amd64-linux-", "x86-64-linux-" ]);
 
 # All environment variables for compiler and binutils with their corresponding
 # application name which will be modified for cross-compiling.
